agentle.agents.a2a.tasks.task\_status\_update\_event
====================================================

.. automodule:: agentle.agents.a2a.tasks.task_status_update_event

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      Any
      BaseModel
      TaskStatus
      TaskStatusUpdateEvent
   